@@ -3,14 +3,15 @@ import threading
 import time
 from pathlib import Path
 from typing import Any, Iterable, Optional
-from typing_extensions import Literal, TypedDict
+
+from typing_extensions import Final, Literal, TypedDict
 
 import proofaday.constants as consts
 
 StatusData = TypedDict("StatusData", {"pid": int, "host": str, "port": int})
 Key = Literal["pid", "host", "port"]
 
-KEYS: Iterable[Key] = ["pid", "host", "port"]
+KEYS: Final[Iterable[Key]] = ["pid", "host", "port"]
 
 
 class StatusError(Exception):
@@ -18,7 +19,7 @@ class StatusError(Exception):
 
 
 class Status:
-    poll_interval = 0.5
+    poll_interval: Final = 0.5
 
     def __init__(self, path: Path) -> None:
         self.file = path / consts.STATUS_FILE
@@ -55,7 +56,11 @@ class Status:
 
     def wait(self, exist: bool, timeout: Optional[float] = 1.5) -> bool:
         stop = threading.Event()
-        wait_thread = threading.Thread(target=self._wait, args=(exist, stop))
+        wait_thread = threading.Thread(
+            target=self._wait,
+            args=(exist, stop),
+            daemon=True,
+        )
         wait_thread.start()
         wait_thread.join(timeout=timeout)
         stop.set()
